package org.eclipse.papyrus.cpp.codegen.xtend;

import com.google.common.base.Objects;
import java.util.ArrayList;
import java.util.List;
import org.eclipse.emf.common.util.EList;
import org.eclipse.papyrus.C_Cpp.CppRoot;
import org.eclipse.papyrus.C_Cpp.External;
import org.eclipse.papyrus.C_Cpp.NoCodeGen;
import org.eclipse.papyrus.codegen.base.GenUtils;
import org.eclipse.papyrus.cpp.codegen.utils.ClassUtils;
import org.eclipse.papyrus.cpp.codegen.utils.CppGenUtils;
import org.eclipse.papyrus.cpp.codegen.xtend.CppClassIncludeDeclaration;
import org.eclipse.uml2.uml.Classifier;
import org.eclipse.uml2.uml.DataType;
import org.eclipse.uml2.uml.Element;
import org.eclipse.uml2.uml.Enumeration;
import org.eclipse.uml2.uml.PrimitiveType;
import org.eclipse.xtext.xbase.lib.Functions.Function1;
import org.eclipse.xtext.xbase.lib.IterableExtensions;

/**
 * @author Önder GÜRCAN (onder.gurcan@cea.fr)
 */
@SuppressWarnings("all")
public class CppClassIncludeClassDeclaration {
  public static String cppOwnerPackageIncludePath(final org.eclipse.uml2.uml.Package pkg) {
    boolean _and = false;
    boolean _notEquals = (!Objects.equal(pkg, null));
    if (!_notEquals) {
      _and = false;
    } else {
      boolean _hasStereotype = GenUtils.hasStereotype(pkg, CppRoot.class);
      boolean _not = (!_hasStereotype);
      _and = _not;
    }
    if (_and) {
      String _fullPath = GenUtils.getFullPath(pkg);
      String _plus = (_fullPath + "/Pkg_");
      String _name = pkg.getName();
      String _plus_1 = (_plus + _name);
      return (_plus_1 + ".h");
    } else {
      return null;
    }
  }
  
  public static Iterable<String> CppClassAllIncludesDeclarationBody(final Classifier classifier) {
    EList<Classifier> _includedImplementationClassifiers = ClassUtils.includedImplementationClassifiers(classifier);
    return CppClassIncludeClassDeclaration.cppClassAllIncludes(classifier, _includedImplementationClassifiers);
  }
  
  public static Iterable<String> cppClassAllIncludes(final Classifier classifier, final EList<Classifier> list) {
    List<String> newList = new ArrayList<String>();
    for (final Classifier cl : list) {
      boolean _or = false;
      boolean _and = false;
      boolean _notEquals = (!Objects.equal(cl, classifier));
      if (!_notEquals) {
        _and = false;
      } else {
        boolean _hasStereotype = GenUtils.hasStereotype(cl, NoCodeGen.class);
        boolean _not = (!_hasStereotype);
        _and = _not;
      }
      if (_and) {
        _or = true;
      } else {
        boolean _hasStereotype_1 = GenUtils.hasStereotype(cl, External.class);
        _or = _hasStereotype_1;
      }
      if (_or) {
        boolean _or_1 = false;
        if ((cl instanceof Enumeration)) {
          _or_1 = true;
        } else {
          _or_1 = (cl instanceof PrimitiveType);
        }
        if (_or_1) {
          boolean _and_1 = false;
          Element _owner = cl.getOwner();
          if (!(_owner instanceof org.eclipse.uml2.uml.Package)) {
            _and_1 = false;
          } else {
            Element _owner_1 = cl.getOwner();
            Element _owner_2 = classifier.getOwner();
            boolean _notEquals_1 = (!Objects.equal(_owner_1, _owner_2));
            _and_1 = _notEquals_1;
          }
          if (_and_1) {
            Element _owner_3 = cl.getOwner();
            String includePath = CppClassIncludeClassDeclaration.cppOwnerPackageIncludePath(((org.eclipse.uml2.uml.Package) _owner_3));
            boolean _contains = newList.contains(includePath);
            boolean _not_1 = (!_contains);
            if (_not_1) {
              newList.add(includePath);
            }
          } else {
          }
        } else {
          List<String> _cppClassIncludes = CppClassIncludeDeclaration.cppClassIncludes(cl);
          newList.addAll(_cppClassIncludes);
        }
      } else {
      }
    }
    final Function1<String, Boolean> _function = new Function1<String, Boolean>() {
      public Boolean apply(final String str) {
        return Boolean.valueOf((!Objects.equal(str, null)));
      }
    };
    return IterableExtensions.<String>filter(newList, _function);
  }
  
  public static Iterable<String> cppClassAllDeclares(final Classifier classifier, final EList<Classifier> declaredClassifiers, final EList<Classifier> includedClassifiers) {
    List<String> newList = new ArrayList<String>();
    boolean _notEquals = (!Objects.equal(declaredClassifiers, null));
    if (_notEquals) {
      boolean _notEquals_1 = (!Objects.equal(includedClassifiers, null));
      if (_notEquals_1) {
        declaredClassifiers.removeAll(includedClassifiers);
      }
      for (final Classifier cl : declaredClassifiers) {
        boolean _or = false;
        boolean _and = false;
        boolean _notEquals_2 = (!Objects.equal(cl, classifier));
        if (!_notEquals_2) {
          _and = false;
        } else {
          boolean _hasStereotype = GenUtils.hasStereotype(cl, NoCodeGen.class);
          boolean _not = (!_hasStereotype);
          _and = _not;
        }
        if (_and) {
          _or = true;
        } else {
          boolean _hasStereotype_1 = GenUtils.hasStereotype(cl, External.class);
          _or = _hasStereotype_1;
        }
        if (_or) {
          String declaration = "";
          if (((!(cl instanceof Enumeration)) && (!(cl instanceof PrimitiveType)))) {
            if ((cl instanceof DataType)) {
              String _openNSMinimal = CppGenUtils.openNSMinimal(cl);
              String _plus = (_openNSMinimal + "struct ");
              String _name = ((DataType)cl).getName();
              String _plus_1 = (_plus + _name);
              String _plus_2 = (_plus_1 + ";");
              String _closeNSMinimal = CppGenUtils.closeNSMinimal(cl);
              String _plus_3 = (_plus_2 + _closeNSMinimal);
              declaration = _plus_3;
            } else {
              String _openNSMinimal_1 = CppGenUtils.openNSMinimal(cl);
              String _replaceAll = _openNSMinimal_1.replaceAll("\r", "");
              String _replaceAll_1 = _replaceAll.replaceAll("\n", "");
              String _plus_4 = (_replaceAll_1 + "class ");
              String _name_1 = cl.getName();
              String _plus_5 = (_plus_4 + _name_1);
              String _plus_6 = (_plus_5 + ";");
              String _closeNSMinimal_1 = CppGenUtils.closeNSMinimal(cl);
              String _replaceAll_2 = _closeNSMinimal_1.replaceAll("\r", "");
              String _replaceAll_3 = _replaceAll_2.replaceAll("\n", "");
              String _plus_7 = (_plus_6 + _replaceAll_3);
              declaration = _plus_7;
            }
          }
          boolean _notEquals_3 = (!Objects.equal(declaration, ""));
          if (_notEquals_3) {
            boolean _contains = newList.contains(declaration);
            boolean _not_1 = (!_contains);
            if (_not_1) {
              newList.add(declaration);
            }
          }
        }
      }
    }
    final Function1<String, Boolean> _function = new Function1<String, Boolean>() {
      public Boolean apply(final String str) {
        return Boolean.valueOf((!Objects.equal(str, null)));
      }
    };
    return IterableExtensions.<String>filter(newList, _function);
  }
  
  public static Iterable<String> CppClassAllIncludes(final Classifier clazz) {
    EList<Classifier> _includedClassifiers = ClassUtils.includedClassifiers(clazz);
    return CppClassIncludeClassDeclaration.cppClassAllIncludes(clazz, _includedClassifiers);
  }
  
  public static Iterable<String> CppClassAllDeclares(final Classifier clazz) {
    EList<Classifier> _declaredClassifiers = ClassUtils.declaredClassifiers(clazz);
    EList<Classifier> _includedClassifiers = ClassUtils.includedClassifiers(clazz);
    return CppClassIncludeClassDeclaration.cppClassAllDeclares(clazz, _declaredClassifiers, _includedClassifiers);
  }
}
